==> tapir-openapi-docs_3-1.11.6-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"tapir-openapi-docs","t":"tapir-openapi-docs","d":"","k":"static","x":""},
{"l":"sttp/tapir/docs/openapi.html#","e":false,"i":"","n":"sttp.tapir.docs.openapi","t":"sttp.tapir.docs.openapi","d":"","k":"package","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#","e":false,"i":"","n":"OpenAPIDocsInterpreter","t":"OpenAPIDocsInterpreter","d":"sttp.tapir.docs.openapi","k":"trait","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#openAPIDocsOptions-0","e":false,"i":"","n":"openAPIDocsOptions","t":"openAPIDocsOptions: OpenAPIDocsOptions","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#serverEndpointsToOpenAPI-fffffbfb","e":false,"i":"","n":"serverEndpointsToOpenAPI","t":"serverEndpointsToOpenAPI[F[_]](ses: Iterable[ServerEndpoint[_, F]], title: String, version: String): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#serverEndpointsToOpenAPI-fffffb95","e":false,"i":"","n":"serverEndpointsToOpenAPI","t":"serverEndpointsToOpenAPI[F[_]](ses: Iterable[ServerEndpoint[_, F]], info: Info): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#serverEndpointsToOpenAPI-32d","e":false,"i":"","n":"serverEndpointsToOpenAPI","t":"serverEndpointsToOpenAPI[F[_]](ses: Iterable[ServerEndpoint[_, F]], info: Info, docsExtensions: List[DocsExtension[_]]): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-ffffff45","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[A, I, E, O, R](e: Endpoint[A, I, E, O, R], title: String, version: String): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-78b","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[A, I, E, O, R](e: Endpoint[A, I, E, O, R], info: Info): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-877","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[A, I, E, O, R](e: Endpoint[A, I, E, O, R], info: Info, docsExtensions: List[DocsExtension[_]]): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-474","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[R, F[_]](se: ServerEndpoint[R, F], title: String, version: String): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-93c","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[R, F[_]](se: ServerEndpoint[R, F], info: Info): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-a6","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[R, F[_]](se: ServerEndpoint[R, F], info: Info, docsExtensions: List[DocsExtension[_]]): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-fffffb8c","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI(es: Iterable[AnyEndpoint], title: String, version: String): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-d24","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI(es: Iterable[AnyEndpoint], info: Info): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-ffffffbe","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI(es: Iterable[AnyEndpoint], info: Info, docsExtensions: List[DocsExtension[_]]): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter$.html#","e":false,"i":"","n":"OpenAPIDocsInterpreter","t":"OpenAPIDocsInterpreter","d":"sttp.tapir.docs.openapi","k":"object","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter$.html#apply-5fe","e":false,"i":"","n":"apply","t":"apply(docsOptions: OpenAPIDocsOptions): OpenAPIDocsInterpreter","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsOptions.html#","e":false,"i":"","n":"OpenAPIDocsOptions","t":"OpenAPIDocsOptions(operationIdGenerator: (AnyEndpoint, Vector[String], Method) => String, schemaName: SName => String, defaultDecodeFailureOutput: (EndpointInput[_]) => Option[EndpointOutput[_]], markOptionsAsNullable: Boolean, failOnDuplicateOperationId: Boolean)","d":"sttp.tapir.docs.openapi","k":"class","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsOptions$.html#","e":false,"i":"","n":"OpenAPIDocsOptions","t":"OpenAPIDocsOptions","d":"sttp.tapir.docs.openapi","k":"object","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsOptions$.html#default-0","e":false,"i":"","n":"default","t":"default: OpenAPIDocsOptions","d":"sttp.tapir.docs.openapi.OpenAPIDocsOptions","k":"val","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsOptions$.html#defaultDecodeFailureOutput-0","e":false,"i":"","n":"defaultDecodeFailureOutput","t":"defaultDecodeFailureOutput: (EndpointInput[_]) => Option[EndpointOutput[_]]","d":"sttp.tapir.docs.openapi.OpenAPIDocsOptions","k":"val","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsOptions$.html#defaultOperationIdGenerator-0","e":false,"i":"","n":"defaultOperationIdGenerator","t":"defaultOperationIdGenerator: (AnyEndpoint, Vector[String], Method) => String","d":"sttp.tapir.docs.openapi.OpenAPIDocsOptions","k":"val","x":""}];

==> tapir-openapi-docs_3-1.12.4-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"tapir-openapi-docs","t":"tapir-openapi-docs","d":"","k":"static","x":""},
{"l":"sttp/tapir/docs/openapi.html#","e":false,"i":"","n":"sttp.tapir.docs.openapi","t":"sttp.tapir.docs.openapi","d":"","k":"package","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#","e":false,"i":"","n":"OpenAPIDocsInterpreter","t":"OpenAPIDocsInterpreter","d":"sttp.tapir.docs.openapi","k":"trait","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#openAPIDocsOptions-0","e":false,"i":"","n":"openAPIDocsOptions","t":"openAPIDocsOptions: OpenAPIDocsOptions","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#serverEndpointsToOpenAPI-fffffbfb","e":false,"i":"","n":"serverEndpointsToOpenAPI","t":"serverEndpointsToOpenAPI[F[_]](ses: Iterable[ServerEndpoint[_, F]], title: String, version: String): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#serverEndpointsToOpenAPI-fffffb95","e":false,"i":"","n":"serverEndpointsToOpenAPI","t":"serverEndpointsToOpenAPI[F[_]](ses: Iterable[ServerEndpoint[_, F]], info: Info): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#serverEndpointsToOpenAPI-32d","e":false,"i":"","n":"serverEndpointsToOpenAPI","t":"serverEndpointsToOpenAPI[F[_]](ses: Iterable[ServerEndpoint[_, F]], info: Info, docsExtensions: List[DocsExtension[_]]): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-ffffff45","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[A, I, E, O, R](e: Endpoint[A, I, E, O, R], title: String, version: String): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-78b","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[A, I, E, O, R](e: Endpoint[A, I, E, O, R], info: Info): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-877","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[A, I, E, O, R](e: Endpoint[A, I, E, O, R], info: Info, docsExtensions: List[DocsExtension[_]]): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-474","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[R, F[_]](se: ServerEndpoint[R, F], title: String, version: String): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-93c","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[R, F[_]](se: ServerEndpoint[R, F], info: Info): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-a6","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI[R, F[_]](se: ServerEndpoint[R, F], info: Info, docsExtensions: List[DocsExtension[_]]): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-fffffb8c","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI(es: Iterable[AnyEndpoint], title: String, version: String): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-d24","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI(es: Iterable[AnyEndpoint], info: Info): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter.html#toOpenAPI-ffffffbe","e":false,"i":"","n":"toOpenAPI","t":"toOpenAPI(es: Iterable[AnyEndpoint], info: Info, docsExtensions: List[DocsExtension[_]]): OpenAPI","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter$.html#","e":false,"i":"","n":"OpenAPIDocsInterpreter","t":"OpenAPIDocsInterpreter","d":"sttp.tapir.docs.openapi","k":"object","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsInterpreter$.html#apply-5fe","e":false,"i":"","n":"apply","t":"apply(docsOptions: OpenAPIDocsOptions = ...): OpenAPIDocsInterpreter","d":"sttp.tapir.docs.openapi.OpenAPIDocsInterpreter","k":"def","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsOptions.html#","e":false,"i":"","n":"OpenAPIDocsOptions","t":"OpenAPIDocsOptions(operationIdGenerator: (AnyEndpoint, Vector[String], Method) => String, schemaName: SName => String = ..., defaultDecodeFailureOutput: (EndpointInput[_]) => Option[EndpointOutput[_]] = ..., markOptionsAsNullable: Boolean = ..., failOnDuplicateOperationId: Boolean = ...)","d":"sttp.tapir.docs.openapi","k":"class","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsOptions$.html#","e":false,"i":"","n":"OpenAPIDocsOptions","t":"OpenAPIDocsOptions","d":"sttp.tapir.docs.openapi","k":"object","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsOptions$.html#default-0","e":false,"i":"","n":"default","t":"default: OpenAPIDocsOptions","d":"sttp.tapir.docs.openapi.OpenAPIDocsOptions","k":"val","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsOptions$.html#defaultDecodeFailureOutput-0","e":false,"i":"","n":"defaultDecodeFailureOutput","t":"defaultDecodeFailureOutput: (EndpointInput[_]) => Option[EndpointOutput[_]]","d":"sttp.tapir.docs.openapi.OpenAPIDocsOptions","k":"val","x":""},
{"l":"sttp/tapir/docs/openapi/OpenAPIDocsOptions$.html#defaultOperationIdGenerator-0","e":false,"i":"","n":"defaultOperationIdGenerator","t":"defaultOperationIdGenerator: (AnyEndpoint, Vector[String], Method) => String","d":"sttp.tapir.docs.openapi.OpenAPIDocsOptions","k":"val","x":""}];
